A graph based queryable object persistance framework built on top of Neo4j.

Build status
------------

.. image:: https://secure.travis-ci.org/onefinestay/kaiso.png?branch=master
   :target: http://travis-ci.org/onefinestay/kaiso
